<?php

require_once('image_fetcher.php'); 	// image retrieval and processing
require_once('database.php');		// database operations

function serverUrl($return_subfolder = false)
{ // get the protocol, domain name and path
    $https = (!empty($_SERVER['HTTPS']) && (strtolower($_SERVER['HTTPS'])=='on')) || $_SERVER["SERVER_PORT"]=='443'; // HTTPS detection.
    $serverport = ($_SERVER["SERVER_PORT"]=='80' || ($https && $_SERVER["SERVER_PORT"]=='443') ? '' : ':'.$_SERVER["SERVER_PORT"]);
    if($return_subfolder === true) {
        $path = pathinfo( $_SERVER['PHP_SELF'] );
        $subfolder = $path['dirname'] .'/';
    } else $subfolder = '';
    return 'http'.($https?'s':'').'://'.$_SERVER["SERVER_NAME"].$serverport.$subfolder;
}

// get item information (fetch new or update expired, if applicable)
function get_id($id, $instance, $expiration = 2592000)  // default: 30 days expiration
{
 $error=array();$getdata = FALSE;
 $expire = time() -$expiration ; 

 if(blacklistIdCheck($id) !== FALSE) {  // blacklisted item ?
  $error[] = 'blacklisted';
  if(blacklistIdCheck($id) < $expire) {blacklistIdCheck($id, TRUE);} // reset expired blacklist
  return FALSE;
 }

 $getdata = getDataId($id);
 if($getdata == FALSE or $getdata[0]['updated'] < $expire) // no data returned (unknown item) or expired item: let's get !
 {


 if(metadata($id, $instance) !== FALSE and empty($error))
  { 
   // processing the output from the modules
   $meta = json_decode(metadata($id, $instance), TRUE);
   $fetch = json_decode(image_fetcher($meta['file_url'], $meta['remote_page'], $meta['id'], $meta['format'], $meta['created_at'], $meta['checksum']), TRUE); 
  }
 else {
  $error[] = '404';
  if($id < newestrow())
    blacklistId($id);   // blacklisting item in the past
  }

 if(isset($fetch) && $fetch['status'] == 'ok')
  {
  // data collecting before insertion
  $result = array('id'	=>$meta['id'], 'created_at'=>$meta['created_at'], 'updated'=>time(), 'author'=>$meta['author'], 'file_url'=>$meta['file_url'], 'file_url_local'=>$fetch['file_url_local'], 'file_url_local_thumbnail'=>$fetch['file_url_local_thumbnail'], 'tags'=>$meta['tags'], 'tags_character'=>$meta['tags_character'], 'tags_work'=>$meta['tags_work'], 'tags_artist'=>$meta['tags_artist'], 'source'=>$meta['source'], 'rating'=>$meta['rating'], 'score'=>$meta['score'], 'format'=>$meta['format'], 'width'=>$fetch['width'], 'height'=>$fetch['height'], 'file_size'=>$fetch['file_size'], 'checksum'=>$fetch['checksum'], 'checksum_sha1'=>$fetch['checksum_sha1']);
 // final formatting and database insertion
  insertOrUpdate($result['id'], $result['created_at'], $result['updated'], $result['author'], $result['file_url'], $result['file_url_local'], $result['file_url_local_thumbnail'], json_encode($result['tags']), json_encode($result['tags_character']), json_encode($result['tags_work']), json_encode($result['tags_artist']), $result['source'], $result['rating'], $result['score'], $result['format'], $result['width'], $result['height'], $result['file_size'], $result['checksum'], $result['checksum_sha1']);
  
  $getdata = getDataId($result['id']) or $error[] = 'database malfunction';  // let's get the new data; if something's wrong here, we screwed the DB
  }
  else $error[] = 'error: ';
 }

if(empty($error))
 {
 // tags formatting
 $getdata[0]['tags'] = json_decode($getdata[0]['tags'], TRUE);$getdata[0]['tags_character'] = json_decode($getdata[0]['tags_character'], TRUE);$getdata[0]['tags_work'] = json_decode($getdata[0]['tags_work'], TRUE);$getdata[0]['tags_artist'] = json_decode($getdata[0]['tags_artist'], TRUE);
 $output=array();
 foreach($getdata[0] as $key=>$value) {
  $output[$key]=$value;
  }

 return json_encode($output); // pass the data back to index
 }
else
 return FALSE;

}

// tag formatting scheme. We use two modes: CSV for plaintext list (title, alt,..), and DETAILS for formatted lists including search links
function tagformat($format, $tags_artist=array(), $tags_work=array(), $tags_character=array(), $tags=array())
{
 if($format == 'csv')
 {
 $output = implode(',', array_merge(json_decode($tags_artist, TRUE), json_decode($tags_work, TRUE), json_decode($tags_character, TRUE), json_decode($tags, TRUE)));
 return $output;
 }

 else if ($format == 'details')
 {
 $tags = json_decode($tags, TRUE);
 $tags_character = json_decode($tags_character, TRUE);
 $tags_work = json_decode($tags_work, TRUE);
 $tags_artist = json_decode($tags_artist, TRUE);
 $output = '';
  if(!empty($tags_artist)) {
	foreach($tags_artist as $item) { $output.= '<li class="tags_artist"><a title="artist" href="./?s='.html_entity_decode($item).'">'.$item.'</a></li>'; }
   }

  if(!empty($tags_work)) {
	foreach($tags_work as $item) { $output.= '<li class="tags_work"><a title="work" href="./?s='.html_entity_decode($item).'">'.$item.'</a></li>'; }
   }

  if(!empty($tags_character)) {
	foreach($tags_character as $item) { $output.= '<li class="tags_characters"><a title="character" href="./?s='.html_entity_decode($item).'">'.$item.'</a></li>'; }
   }

  if(!empty($tags)) {
	$outgen = ''; foreach($tags as $item) { $outgen.= '<li class="tags_generic"><a href="./?s='.html_entity_decode($item).'">'.$item.'</a></li>'; }
        $output.= $outgen;
   }
 $output = '<ul>'.$output.'</ul>';
 return $output;
 }
}

// rating code translation
function itemrating($rating)
{
$out = '';
if($rating == 's') $out = 'Safe';
if($rating == 'q') $out = 'Questionable';
if($rating == 'e') $out = 'Explicit';
return $out;
}

// file size formatting ( bytes -> megabytes )
function itemsize($filesize)
{
$filesize = (int)$filesize;
$filesize = round($filesize/1048576, 2);
return $filesize;
}


?>
